@@ -80,10 +80,11 @@ class FileManager(threading.Thread):
         if not os.path.isfile(full_path):
             return empty_dict
 
+        # RFC 7159: JSON should be represented by UTF-8
         with open(
             full_path,
             'r',
-            encoding=utils.get_encoding(),
+            encoding='UTF-8',
             errors='ignore',
         ) as json_file:
 
@@ -118,7 +119,7 @@ class FileManager(threading.Thread):
         with open(
             full_path,
             'r',
-            encoding=utils.get_encoding(),
+            encoding='UTF-8',
             errors='ignore',
         ) as text_file:
 
