@@ -65,6 +65,12 @@ class OptionsManager(object):
         abort_on_error (bool): If True, youtube-dl will abord downloading
             further playlist videos if an error occurs
 
+        live_from_start (bool): If True, downloads livestreams from the start.
+            Currently only supported for YouTube (and marked experimental)
+
+        wait_for_video_min (int): Minimum number of seconds to wait between
+            retries for scheduled livestreams to become available (in seconds)
+
     NETWORK OPTIONS
 
         proxy (str): Use the specified HTTP/HTTPS proxy. If none is specified,
@@ -102,6 +108,12 @@ class OptionsManager(object):
 
         playlist_end (int): Playlist index to stop downloading
 
+        playlist_items (str): Comma-separated playlist index of the videos to
+            download, in the form '[START]:[STOP][:STEP]' or 'START-STOP'. Use
+            negative indices to count from the right and negative STEP to
+            download in reverse order, e.g. on a playhlist of 15 videos,
+            '1:3,7,-5::2' downloads the videos at index '1,2,3,7,11,13,15'
+
         max_downloads (int): Maximum number of video files to download from the
             given playlist
 
@@ -476,7 +488,7 @@ class OptionsManager(object):
 
     YOUTUBE-DL-GUI OPTIONS (not passed to youtube-dl directly)
 
-        [used to build the 'save_path_list' option]
+        [used to build parameters of --output and --paths]
 
         output_format (int): Option in the range 0-9, which is converted into
             a youtube-dl output template using
@@ -486,7 +498,7 @@ class OptionsManager(object):
         output_template (str): Can be any output template supported by
             youtube-dl. Ignored if 'output_format' is not 0
 
-        [used in conjunction with the 'min_filesize' and 'max_filesize' options
+        [used in conjunction with the 'min_filesize' & 'max_filesize' options]
 
             max_filesize_unit (str): Maximum file size unit. Available values:
                 '' (for bytes), 'k' (for kilobytes, etc), 'm', 'g', 't', 'p',
@@ -595,13 +607,6 @@ class OptionsManager(object):
             ('~/.config/youtube-dl/config'). On MS Windows, a file in the
             Tartube directory is used (youtube-dl.conf)
 
-        save_path_list (list): List of arguments used with the '--output'
-            parameter. Contains the output template. If the 'output_path_list'
-            option is not specified, then the template is preceded by the
-            output directory. Arguments are constructed in a call to
-            OptionsParser.build_save_path(), and cannot be set directly by the
-            user
-
     """
 
 
@@ -720,6 +725,8 @@ class OptionsManager(object):
             # OPTIONS
             'ignore_errors': True,
             'abort_on_error': False,
+            'live_from_start': False,
+            'wait_for_video_min': 0,
             # NETWORK OPTIONS
             'proxy': '',
             'socket_timeout': '',
@@ -735,6 +742,7 @@ class OptionsManager(object):
             # VIDEO SELECTION
             'playlist_start': 1,
             'playlist_end': 0,
+            'playlist_items': '',
             'max_downloads': 0,
             'min_filesize': 0,
             'max_filesize': 0,
@@ -884,7 +892,6 @@ class OptionsManager(object):
             'video_format_mode': 'single',
             'subs_lang_list': [ 'en' ],
             'downloader_config': False,
-            'save_path_list': [],
         }
 
 
@@ -1007,6 +1014,10 @@ class OptionsParser(object):
             OptionHolder('ignore_errors', '-i', False),
             # --abort-on-error
             OptionHolder('abort_on_error', '--abort-on-error', False),
+            # --live-from-start
+            OptionHolder('live_from_start', '--live-from-start', False),
+            # --wait-for-video MIN (N.B. the MAX value is not supported)
+            OptionHolder('wait_for_video_min', '--wait-for-video', 0),
             # NETWORK OPTIONS
             # --proxy URL
             OptionHolder('proxy', '--proxy', ''),
@@ -1038,6 +1049,8 @@ class OptionsParser(object):
             OptionHolder('playlist_start', '--playlist-start', 1),
             # --playlist-end NUMBER
             OptionHolder('playlist_end', '--playlist-end', 0),
+            # --playlist-items ITEM_SPEC
+            OptionHolder('playlist_items', '--playlist-items', ''),
             # --max-downloads NUMBER
             OptionHolder('max_downloads', '--max-downloads', 0),
             # --min-filesize SIZE
@@ -1342,7 +1355,6 @@ class OptionsParser(object):
 #           OptionHolder('video_format_mode', '', 'single'),
 #           OptionHolder('subs_lang_list', '', []),
 #           OptionHolder('downloader_config', '', False),
-#           OptionHolder('save_path_list', '', []),
         ]
 
 
@@ -1447,8 +1459,20 @@ class OptionsParser(object):
                             options_list.append(option_holder_obj.switch)
                             options_list.append(utils.to_string(value))
 
-            elif option_holder_obj.name == 'match_filter' \
-            or option_holder_obj.name == 'external_arg_string' \
+            elif option_holder_obj.name == 'match_filter':
+                value = utils.to_string(copy_dict[option_holder_obj.name])
+                if self.app_obj.block_livestreams_flag:
+
+                    if value == '':
+                        value = '!is_live'
+                    else:
+                        value += ' \& !is_live'
+
+                if value != '':
+                    options_list.append(option_holder_obj.switch)
+                    options_list.append(value)
+
+            elif option_holder_obj.name == 'external_arg_string' \
             or option_holder_obj.name == 'pp_args':
                 value = copy_dict[option_holder_obj.name]
                 if value != '':
@@ -1516,7 +1540,7 @@ class OptionsParser(object):
             options_list.append('--extractor-args')
             options_list.append(item)
 
-        # Parse the 'save_path_list' option
+        # Build the --output and --paths options
         options_list = self.build_paths(
             dir_path,
             copy_dict,
@@ -1717,8 +1741,8 @@ class OptionsParser(object):
 
         """Called by self.parse().
 
-        Build the value of the 'save_path_list' option, and add it directly to
-        the options list.
+        Build the --output and --paths options, adding them directly to the
+        options list.
 
         Args:
 
